@@ -18,13 +18,13 @@ var _ = Describe("generating source", func() {
 	)
 
 	BeforeEach(func() {
-		generator, err = NewConfigGenerator(false, false)
+		generator, err = NewConfigGenerator(false, false, true)
 		Expect(err).To(BeNil())
 	})
 
 	Context("for only logs.app source", func() {
 		BeforeEach(func() {
-			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeApp)))
+			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeApp)), sets.NewString())
 			Expect(err).To(BeNil())
 			Expect(len(results) == 1).To(BeTrue())
 		})
@@ -37,6 +37,7 @@ var _ = Describe("generating source", func() {
 			path "/var/log/containers/*.log"
 			exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
 			pos_file "/var/log/es-containers.log.pos"
+			pos_file_compaction_interval 1800
 			refresh_interval 5
 			rotate_wait 5
 			tag kubernetes.*
@@ -63,7 +64,7 @@ var _ = Describe("generating source", func() {
 
 	Context("for only logs.infra source", func() {
 		BeforeEach(func() {
-			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeInfra)))
+			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeInfra)), sets.NewString())
 			Expect(err).To(BeNil())
 			Expect(len(results) == 1).To(BeTrue())
 		})
@@ -93,7 +94,7 @@ var _ = Describe("generating source", func() {
 
 	Context("for only logs.audit source", func() {
 		BeforeEach(func() {
-			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeAudit)))
+			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeAudit)), sets.NewString())
 			Expect(err).To(BeNil())
 			Expect(len(results)).To(Equal(3))
 		})
@@ -107,6 +108,7 @@ var _ = Describe("generating source", func() {
               @label @INGRESS
               path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
               pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+              pos_file_compaction_interval 1800
               tag linux-audit.log
               <parse>
                 @type viaq_host_audit
@@ -121,6 +123,7 @@ var _ = Describe("generating source", func() {
               @label @INGRESS
               path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
               pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+              pos_file_compaction_interval 1800
               tag k8s-audit.log
               <parse>
                 @type json
@@ -139,6 +142,7 @@ var _ = Describe("generating source", func() {
               @label @INGRESS
               path "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log'}"
               pos_file "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log.pos'}"
+              pos_file_compaction_interval 1800
               tag openshift-audit.log
               <parse>
                 @type json
@@ -155,7 +159,7 @@ var _ = Describe("generating source", func() {
 	Context("for all log sources", func() {
 
 		BeforeEach(func() {
-			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeApp), string(logging.LogSourceTypeInfra), string(logging.LogSourceTypeAudit)))
+			results, err = generator.generateSource(sets.NewString(string(logging.LogSourceTypeApp), string(logging.LogSourceTypeInfra), string(logging.LogSourceTypeAudit)), sets.NewString())
 			Expect(err).To(BeNil())
 			Expect(len(results)).To(Equal(5))
 		})
@@ -193,6 +197,7 @@ var _ = Describe("generating source", func() {
 				path "/var/log/containers/*.log"
 				exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
 				pos_file "/var/log/es-containers.log.pos"
+				pos_file_compaction_interval 1800
 				refresh_interval 5
 				rotate_wait 5
 				tag kubernetes.*
@@ -228,6 +233,7 @@ var _ = Describe("generating source", func() {
                 @label @INGRESS
                 path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
                 pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+                pos_file_compaction_interval 1800
                 tag linux-audit.log
                 <parse>
                   @type viaq_host_audit
@@ -242,6 +248,7 @@ var _ = Describe("generating source", func() {
                 @label @INGRESS
                 path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
                 pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+                pos_file_compaction_interval 1800
                 tag k8s-audit.log
                 <parse>
                   @type json
@@ -260,6 +267,7 @@ var _ = Describe("generating source", func() {
                 @label @INGRESS
                 path "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log'}"
                 pos_file "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log.pos'}"
+                pos_file_compaction_interval 1800
                 tag openshift-audit.log
                 <parse>
                   @type json
